@@ -5,7 +5,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use base qw/Import::Export/;
 
@@ -30,7 +30,7 @@ Const::XS - Facility for creating read-only scalars, arrays, hashes
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
@@ -99,7 +99,7 @@ The second function exported by this module is make_readonly. It will take a per
 
 The third function exported by this module is make_readonly_ref. It will take a perl struct and deeply make it readonly. Please note that if you call make_readonly_ref the struct will be deeply made readonly however it is 'copied' into the variable and that does not get set as readonly. Take the following example.
 
-	my $ref = make_readonly({a => 1, b => 2, c => 3 }; # we copy into $ref
+	my $ref = make_readonly_ref({a => 1, b => 2, c => 3 }; # we copy into $ref
 	$ref->{d}; # errors
 	$ref = { new => 1 };  # is okay
 
